Skip to main content

calibre-ebook-convert-helper

A helper CLI for calibre's ebook-convert CLI which is used to convert all files in an directory into another format.

Calibre needs to be installed to use this CLI.

Supported sites which are compatible with Calibre can be found here: https://manual.calibre-ebook.com/generated/en/ebook-convert.html

To report issues for the CLI, open an issue at https://github.com/arzkar/calibre-ebook-convert-helper/issues

Installation

From pip (Recommended)

pip install -U ebook-convert-helper

From Github Source (Pre-release, for testing new features by Beta testers)

pip install git+https://github.com/arzkar/calibre-ebook-convert-helper@main

Usage

> ebook-convert-helper --help
usage: ebook-convert-helper [-h] -i INPUT_FORMAT -o OUTPUT_FORMAT --dir
                                    DIR [--delete-file] [-r] [--verbose] [--debug]
                                    [--log] [--version]

A helper CLI for calibre's ebook-convert CLI which is used to convert all files in an directory into another format.

Calibre needs to be installed to use this CLI.

Supported sites which are compatible with Calibre can be found here: https://manual.calibre-ebook.com/generated/en/ebook-convert.html

To report issues for the CLI, open an issue at https://github.com/arzkar/calibre-ebook-convert-helper/issues

optional arguments:
  -h, --help            show this help message and exit
  -i INPUT_FORMAT, --input-format INPUT_FORMAT
                        Input format
  -o OUTPUT_FORMAT, --output-format OUTPUT_FORMAT
                        Output format
  --dir DIR             Absolute Path to the directory
  --delete              Delete all the files containing the Input format
  -r, --recursive       Convert all files from both the directory and its sub-directories
  --ignore              Read directories or files from .echignore which will be excluded from the conversion
  --verbose             Show ebook-convert's stdout
  --debug               Show the log in console
  --log                 Generate a log file in the current directory
  --version             Display version & quit

Example

  • To convert all mobi files inside the directory ~/Books into azw3
ebook-convert-helper -i mobi -o azw3 --dir ~/Books
  • To include all the sub-directories inside the --dir directory, use --recursive
ebook-convert-helper -i mobi -o azw3 --dir ~/Books --recursive
  • To delete the all the files with -i, --input-format i.e. mobi, use --delete
ebook-convert-helper -i mobi -o azw3 --dir ~/Books --delete
  • To ignore directories or files, use --ignore which will read the .echignore file from the root directory specified by --dir and exclude its contents
ebook-convert-helper -i mobi -o azw3 --dir ~/Books --ignore

Note

.echignore file needs to be in the root directory which is specified by --dir. Each directory or file needs to be in its own line and the path can either be relative or absolute.

Metadata

Release files for ebook-convert-helper 0.3.2

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for ebook-convert-helper 0.3.2
File Size Uploaded
ebook-convert-helper-0.3.2.tar.gz 8.9 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for ebook-convert-helper 0.3.2
File Interpreter ABI Platform
ebook_convert_helper-0.3.2-py3-none-any.whl Python 3 none any Details

Total release size: 18.8 kB

Release files / ebook-convert-helper-0.3.2.tar.gz

Download URL ebook-convert-helper-0.3.2.tar.gz
Size 8.9 kB
Tags Source
SHA-256 checksum
How to use checksums
ca7125a42b562b6ffc16216fc81b1ae021e693f12d2f9e2e522491e814059692
BLAKE2b-256 checksum
How to use checksums
e16261532e4f81dbfd702fee21229a96b49e3fac484014b6c0352d478bdf06bf
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/3.8.0 pkginfo/1.8.2 readme-renderer/32.0 requests/2.27.1 requests-toolbelt/0.9.1 urllib3/1.26.9 tqdm/4.63.1 importlib-metadata/4.10.1 keyring/23.5.0 rfc3986/2.0.0 colorama/0.4.4 CPython/3.8.5

Release files / ebook_convert_helper-0.3.2-py3-none-any.whl

Download URL ebook_convert_helper-0.3.2-py3-none-any.whl
Size 9.9 kB
Tags Python 3
SHA-256 checksum
How to use checksums
d462bac845bcce19eb0ee48865a5357bc798a9ce1103af53c5e66b302d8412bc
BLAKE2b-256 checksum
How to use checksums
6e347e4e1c8adbd91ca18fb23e0547f5bcb1652e3dd7b78d33f28ee56bd642d0
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/3.8.0 pkginfo/1.8.2 readme-renderer/32.0 requests/2.27.1 requests-toolbelt/0.9.1 urllib3/1.26.9 tqdm/4.63.1 importlib-metadata/4.10.1 keyring/23.5.0 rfc3986/2.0.0 colorama/0.4.4 CPython/3.8.5

Release history Release notifications | RSS feed

This release

0.3.2 This release

2 release files

0.3.1

2 release files

0.3

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page